@@ -387,6 +387,14 @@ class Organizer:
             List to the paths of all created output files.
 
         """
+        gen = self._inference(epoch=epoch, fileno=fileno)
+        if as_generator:
+            return gen
+        else:
+            return [filename for filename in gen]
+
+    def _inference(self, epoch=None, fileno=None):
+        """ Get generator of doing inference, file by file. """
         if fileno is None and epoch is None:
             epoch, fileno = self.history.get_best_epoch_fileno()
             print("Automatically set epoch to epoch {} file {}.".format(epoch, fileno))
@@ -421,10 +429,7 @@ class Organizer:
                 self, model, files_dict, output_path, use_def_label=False)
             elapsed_s = int(time.time() - start_time)
             print(f'Finished on file {first_filename} in {elapsed_s/60} min')
-            if as_generator:
-                yield output_path
-
-        return filenames
+            yield output_path
 
     def cleanup_models(self):
         """
